@@ -564,10 +564,13 @@ def get_data(file_path, **kwargs):
         Keyword Arguments
         -----------------
 
-            `exclude`=[] {list}
-                A list of keys to exclude from the returning dictionary.
+            `include`=[] {list}
+                A list of keys to include in the returning dictionary.
                 This is primarily useful for limiting the time/size of the operation.
 
+            [`ftp`=None] {object}
+                A reference to the ftputil object to use.
+
         Return
         ----------
         `return` {str}
@@ -842,9 +845,9 @@ def gen_relative_path(src_base, dst_base, file_path):
                 relative_path = file_path[len(src_base):]
             else:
                 relative_path = file_path[src_pos:]
-
-    relative_path = relative_path.replace(dst_base, "")
-    relative_path = relative_path.replace(src_base, "")
+    if relative_path is not None:
+        relative_path = relative_path.replace(dst_base, "")
+        relative_path = relative_path.replace(src_base, "")
     return relative_path
 
 
